@@ -7,13 +7,19 @@ class ConnectedComponentsTests(unittest.TestCase):
         disconnected_graph = Graph(
             {'1': {'2': 3},
              '2': {'1': 3},
-             '3': {}})
+             '3': {'4': 5, '6': 1},
+             '4': {'3': 5},
+             '5': {'6': 2},
+             '6': {'3': 1, '5': 2}})
 
         result = disconnected_graph.decompose_into_connected_components()
         expected = [
             Graph({'1': {'2': 3},
                    '2': {'1': 3}}),
-            Graph({'3': {}})]
+            Graph({'3': {'4': 5, '6': 1},
+                   '4': {'3': 5},
+                   '5': {'6': 2},
+                   '6': {'3': 1, '5': 2}})]
         self.assertEqual(expected, result)
 
     def test_from_connected(self):
