@@ -1,3 +1,6 @@
+import random
+
+
 class Vertex():
     """
     Vertex in a 2 dimensional space.
@@ -15,4 +18,8 @@ class Vertex():
         self.y = y
 
     def __repr__(self):
-        return "%s in (%d, %d)"%(self.obj, self.x, self.y)
\ No newline at end of file
+        return "%s in (%d, %d)"%(self.obj, self.x, self.y)
+
+    def random_position(self, max_x, max_y):
+        self.x = random.random()*max_x
+        self.y = random.random()*max_y
\ No newline at end of file
