@@ -190,10 +190,10 @@ def kamada_kawai_layout(graph, side=10.00, threshold=0.001, K=2.0):
 
     L = side / _max_path(graph)
 
-    lengths = copy.deepcopy(graph.paths)
+    lengths = defaultdict(dict)
     for v1 in graph.vertices:
         for v2 in graph.vertices:
-            lengths[v1][v2] *= L
+            lengths[v1][v2] = graph.paths[v1][v2]*L
 
     strengths = _compute_strengths(graph, K)
 
